@@ -545,12 +545,16 @@ cal_backend_kolab_get_object (ECalBackendSync *backend,
 	if (tmp_err != NULL) {
 		kolab_util_calendar_err_to_edb_err (error, tmp_err, __func__, __LINE__);
 		g_error_free (tmp_err);
+		/* workaround e_util_utf8_make_valid() segfaulting on NULL argument */
+		*calobj = g_strdup ("");
 		return;
 	}
 	if (ecalcomp != NULL) {
 		*calobj = (gchar *) e_cal_component_get_as_string (ecalcomp);
 		g_object_unref (ecalcomp);
-	}
+	} else
+		/* workaround e_util_utf8_make_valid() segfaulting on NULL argument */
+		*calobj = g_strdup ("");
 }
 
 static void
