@@ -140,10 +140,10 @@ G_DEFINE_TYPE (KolabMailInfoDb, kolab_mail_info_db, G_TYPE_OBJECT)
 /* SQLite helpers */
 
 static gboolean
-kolab_mail_info_db_sql_table_create (KolabUtilSqliteDb *kdb,
-                                     const gchar *tblname,
-                                     KolabMailInfoDbTableType tbltype,
-                                     GError **err)
+mail_info_db_sql_table_create (KolabUtilSqliteDb *kdb,
+                               const gchar *tblname,
+                               KolabMailInfoDbTableType tbltype,
+                               GError **err)
 {
 	gchar* sql_str = NULL;
 	gboolean ok = FALSE;
@@ -234,9 +234,9 @@ kolab_mail_info_db_sql_table_create (KolabUtilSqliteDb *kdb,
 }
 
 static gboolean
-kolab_mail_info_db_sql_update_folder (KolabUtilSqliteDb *kdb,
-                                      const KolabFolderSummary *summary,
-                                      GError **err)
+mail_info_db_sql_update_folder (KolabUtilSqliteDb *kdb,
+                                const KolabFolderSummary *summary,
+                                GError **err)
 {
 	gchar *sql_str = NULL;
 	gboolean ok = FALSE;
@@ -276,7 +276,7 @@ kolab_mail_info_db_sql_update_folder (KolabUtilSqliteDb *kdb,
 }
 
 static gchar*
-kolab_mail_info_db_sql_record_new_tblname (const gchar *foldername)
+mail_info_db_sql_record_new_tblname (const gchar *foldername)
 {
 	gchar *tblname = NULL;
 
@@ -289,10 +289,10 @@ kolab_mail_info_db_sql_record_new_tblname (const gchar *foldername)
 }
 
 static gboolean
-kolab_mail_info_db_sql_update_record (KolabUtilSqliteDb *kdb,
-                                      const KolabMailInfoDbRecord *record,
-                                      const gchar *foldername,
-                                      GError **err)
+mail_info_db_sql_update_record (KolabUtilSqliteDb *kdb,
+                                const KolabMailInfoDbRecord *record,
+                                const gchar *foldername,
+                                GError **err)
 {
 	gchar *tblname = NULL;
 	gchar *sql_str = NULL;
@@ -305,11 +305,11 @@ kolab_mail_info_db_sql_update_record (KolabUtilSqliteDb *kdb,
 	g_assert (foldername != NULL);
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
-	tblname = kolab_mail_info_db_sql_record_new_tblname (foldername);
-	ok = kolab_mail_info_db_sql_table_create (kdb,
-	                                          tblname,
-	                                          KOLAB_MAIL_INFO_DB_TABLE_TYPE_RECORD,
-	                                          &tmp_err);
+	tblname = mail_info_db_sql_record_new_tblname (foldername);
+	ok = mail_info_db_sql_table_create (kdb,
+	                                    tblname,
+	                                    KOLAB_MAIL_INFO_DB_TABLE_TYPE_RECORD,
+	                                    &tmp_err);
 	if (! ok) {
 		g_free (tblname);
 		g_propagate_error (err, tmp_err);
@@ -410,7 +410,7 @@ kolab_mail_info_db_sql_update_record (KolabUtilSqliteDb *kdb,
 }
 
 static KolabFolderSummary*
-kolab_mail_info_db_sql_folder_new_from_stmt (sqlite3_stmt *sql_stmt)
+mail_info_db_sql_folder_new_from_stmt (sqlite3_stmt *sql_stmt)
 {
 	KolabFolderSummary *summary = NULL;
 	gchar *tmp_str = NULL;
@@ -468,9 +468,9 @@ kolab_mail_info_db_sql_folder_new_from_stmt (sqlite3_stmt *sql_stmt)
 }
 
 static KolabFolderSummary*
-kolab_mail_info_db_sql_query_folder (KolabUtilSqliteDb *kdb,
-                                     const gchar *foldername,
-                                     GError **err)
+mail_info_db_sql_query_folder (KolabUtilSqliteDb *kdb,
+                               const gchar *foldername,
+                               GError **err)
 {
 	KolabFolderSummary *summary = NULL;
 	gchar *sql_str = NULL;
@@ -511,7 +511,7 @@ kolab_mail_info_db_sql_query_folder (KolabUtilSqliteDb *kdb,
 	}
 
 	/* get new folder summary from prep'ed statement */
-	summary = kolab_mail_info_db_sql_folder_new_from_stmt (sql_stmt);
+	summary = mail_info_db_sql_folder_new_from_stmt (sql_stmt);
 
 	ok = kolab_util_sqlite_fnlz_stmt (kdb, sql_stmt, &tmp_err);
 	if (! ok) {
@@ -524,7 +524,7 @@ kolab_mail_info_db_sql_query_folder (KolabUtilSqliteDb *kdb,
 }
 
 static KolabMailInfoDbRecord*
-kolab_mail_info_db_sql_record_new_from_stmt (sqlite3_stmt *sql_stmt)
+mail_info_db_sql_record_new_from_stmt (sqlite3_stmt *sql_stmt)
 {
 	KolabMailInfoDbRecord* record = NULL;
 	gchar *tmp_str = NULL;
@@ -595,10 +595,10 @@ kolab_mail_info_db_sql_record_new_from_stmt (sqlite3_stmt *sql_stmt)
 }
 
 static KolabMailInfoDbRecord*
-kolab_mail_info_db_sql_query_record (KolabUtilSqliteDb *kdb,
-                                     const gchar *uid,
-                                     const gchar *foldername,
-                                     GError **err)
+mail_info_db_sql_query_record (KolabUtilSqliteDb *kdb,
+                               const gchar *uid,
+                               const gchar *foldername,
+                               GError **err)
 {
 	KolabMailInfoDbRecord *record = NULL;
 	gchar *tblname = NULL;
@@ -615,7 +615,7 @@ kolab_mail_info_db_sql_query_record (KolabUtilSqliteDb *kdb,
 	g_return_val_if_fail (err == NULL || *err == NULL, NULL);
 
 	/* table name */
-	tblname = kolab_mail_info_db_sql_record_new_tblname (foldername);
+	tblname = mail_info_db_sql_record_new_tblname (foldername);
 
 	/* prepare sql statement */
 	sql_str = sqlite3_mprintf ("SELECT * FROM %Q WHERE %q=%Q;",
@@ -646,7 +646,7 @@ kolab_mail_info_db_sql_query_record (KolabUtilSqliteDb *kdb,
 	}
 
 	/* get new InfoDb record from prep'ed statement */
-	record = kolab_mail_info_db_sql_record_new_from_stmt (sql_stmt);
+	record = mail_info_db_sql_record_new_from_stmt (sql_stmt);
 
 	ok = kolab_util_sqlite_fnlz_stmt (kdb, sql_stmt, &tmp_err);
 	g_free (tblname);
@@ -660,9 +660,9 @@ kolab_mail_info_db_sql_query_record (KolabUtilSqliteDb *kdb,
 }
 
 static gboolean
-kolab_mail_info_db_sql_remove_folder (KolabUtilSqliteDb *kdb,
-                                      const gchar *foldername,
-                                      GError **err)
+mail_info_db_sql_remove_folder (KolabUtilSqliteDb *kdb,
+                                const gchar *foldername,
+                                GError **err)
 {
 	gchar *sql_str;
 	gboolean ok = FALSE;
@@ -689,10 +689,10 @@ kolab_mail_info_db_sql_remove_folder (KolabUtilSqliteDb *kdb,
 }
 
 static gboolean
-kolab_mail_info_db_sql_remove_record (KolabUtilSqliteDb *kdb,
-                                      const gchar *uid,
-                                      const gchar *foldername,
-                                      GError **err)
+mail_info_db_sql_remove_record (KolabUtilSqliteDb *kdb,
+                                const gchar *uid,
+                                const gchar *foldername,
+                                GError **err)
 {
 	gchar *tblname = NULL;
 	gchar *sql_str = NULL;
@@ -705,7 +705,7 @@ kolab_mail_info_db_sql_remove_record (KolabUtilSqliteDb *kdb,
 	g_assert (foldername != NULL);
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
-	tblname = kolab_mail_info_db_sql_record_new_tblname (foldername);
+	tblname = mail_info_db_sql_record_new_tblname (foldername);
 
 	sql_str = sqlite3_mprintf ("DELETE FROM %Q WHERE %q=%Q;",
 	                           tblname,
@@ -844,10 +844,10 @@ kolab_mail_info_db_bringup (KolabMailInfoDb *self,
 		g_propagate_error (err, tmp_err);
 		return FALSE;
 	}
-	ok = kolab_mail_info_db_sql_table_create (priv->kdb,
-	                                          KOLAB_MAIL_INFO_DB_SQLITE_DB_TBL_FOLDERS,
-	                                          KOLAB_MAIL_INFO_DB_TABLE_TYPE_FOLDER,
-	                                          &tmp_err);
+	ok = mail_info_db_sql_table_create (priv->kdb,
+	                                    KOLAB_MAIL_INFO_DB_SQLITE_DB_TBL_FOLDERS,
+	                                    KOLAB_MAIL_INFO_DB_TABLE_TYPE_FOLDER,
+	                                    &tmp_err);
 	if (! ok) {
 		g_propagate_error (err, tmp_err);
 		return FALSE;
@@ -933,7 +933,7 @@ kolab_mail_info_db_query_uids (KolabMailInfoDb *self,
 		           __func__);
 
 	/* check for records table existence */
-	tblname = kolab_mail_info_db_sql_record_new_tblname (foldername);
+	tblname = mail_info_db_sql_record_new_tblname (foldername);
 	exists = kolab_util_sqlite_table_exists (priv->kdb, tblname, &tmp_err);
 	if (tmp_err != NULL) {
 		g_free (tblname);
@@ -974,7 +974,7 @@ kolab_mail_info_db_query_uids (KolabMailInfoDb *self,
 		}
 
 		/* read needed values */
-		record = kolab_mail_info_db_sql_record_new_from_stmt (sql_stmt);
+		record = mail_info_db_sql_record_new_from_stmt (sql_stmt);
 		g_assert (record->summary != NULL);
 
 		/* TODO check folder context */
@@ -1052,7 +1052,7 @@ kolab_mail_info_db_query_changed_uids (KolabMailInfoDb *self,
 		           __func__);
 
 	/* check for records table existence */
-	tblname = kolab_mail_info_db_sql_record_new_tblname (foldername);
+	tblname = mail_info_db_sql_record_new_tblname (foldername);
 	exists = kolab_util_sqlite_table_exists (priv->kdb,
 	                                         tblname,
 	                                         &tmp_err);
@@ -1099,7 +1099,7 @@ kolab_mail_info_db_query_changed_uids (KolabMailInfoDb *self,
 		}
 
 		/* read needed values */
-		record = kolab_mail_info_db_sql_record_new_from_stmt (sql_stmt);
+		record = mail_info_db_sql_record_new_from_stmt (sql_stmt);
 		g_assert (record->summary != NULL);
 
 		/* TODO check folder context */
@@ -1235,7 +1235,7 @@ kolab_mail_info_db_query_foldernames (KolabMailInfoDb *self,
 			}
 			break;
 		}
-		summary = kolab_mail_info_db_sql_folder_new_from_stmt (sql_stmt);
+		summary = mail_info_db_sql_folder_new_from_stmt (sql_stmt);
 
 		foldername = kolab_folder_summary_get_char_field (summary,
 		                                                  KOLAB_FOLDER_SUMMARY_CHAR_FIELD_FOLDERNAME);
@@ -1303,9 +1303,9 @@ kolab_mail_info_db_exists_foldername (KolabMailInfoDb *self,
 			return TRUE;
 	}
 
-	summary = kolab_mail_info_db_sql_query_folder (priv->kdb,
-	                                               foldername,
-	                                               &tmp_err);
+	summary = mail_info_db_sql_query_folder (priv->kdb,
+	                                         foldername,
+	                                         &tmp_err);
 	if (tmp_err != NULL) {
 		g_propagate_error (err, tmp_err);
 		return FALSE;
@@ -1345,9 +1345,9 @@ kolab_mail_info_db_query_folder_summary (KolabMailInfoDb *self,
 			return kolab_folder_summary_clone (priv->cache_fs);
 	}
 
-	summary = kolab_mail_info_db_sql_query_folder (priv->kdb,
-	                                               foldername,
-	                                               &tmp_err);
+	summary = mail_info_db_sql_query_folder (priv->kdb,
+	                                         foldername,
+	                                         &tmp_err);
 	if (tmp_err != NULL) {
 		g_propagate_error (err, tmp_err);
 		return NULL;
@@ -1400,9 +1400,9 @@ kolab_mail_info_db_update_folder_summary (KolabMailInfoDb *self,
 	 *      folder and should be deleted on the server
 	 */
 
-	ok = kolab_mail_info_db_sql_update_folder (priv->kdb,
-	                                           summary,
-	                                           &tmp_err);
+	ok = mail_info_db_sql_update_folder (priv->kdb,
+	                                     summary,
+	                                     &tmp_err);
 	if (! ok) {
 		g_propagate_error (err, tmp_err);
 		return FALSE;
@@ -1451,16 +1451,16 @@ kolab_mail_info_db_remove_folder (KolabMailInfoDb *self,
 	}
 
 	/* remove folder summary from folders table */
-	ok = kolab_mail_info_db_sql_remove_folder (priv->kdb,
-	                                           foldername,
-	                                           &tmp_err);
+	ok = mail_info_db_sql_remove_folder (priv->kdb,
+	                                     foldername,
+	                                     &tmp_err);
 	if (! ok) {
 		g_propagate_error (err, tmp_err);
 		return FALSE;
 	}
 
 	/* drop associated records table */
-	tblname = kolab_mail_info_db_sql_record_new_tblname (foldername);
+	tblname = mail_info_db_sql_record_new_tblname (foldername);
 	ok = kolab_util_sqlite_table_drop (priv->kdb, tblname, &tmp_err);
 	g_free (tblname);
 	if (! ok) {
@@ -1555,7 +1555,7 @@ kolab_mail_info_db_query_record (KolabMailInfoDb *self,
 	}
 
 	/* check if record table exists */
-	tblname = kolab_mail_info_db_sql_record_new_tblname (foldername);
+	tblname = mail_info_db_sql_record_new_tblname (foldername);
 	exists = kolab_util_sqlite_table_exists (priv->kdb,
 	                                         tblname,
 	                                         &tmp_err);
@@ -1567,10 +1567,10 @@ kolab_mail_info_db_query_record (KolabMailInfoDb *self,
 	if (! exists)
 		return NULL;
 
-	record = kolab_mail_info_db_sql_query_record (priv->kdb,
-	                                              uid,
-	                                              foldername,
-	                                              &tmp_err);
+	record = mail_info_db_sql_query_record (priv->kdb,
+	                                        uid,
+	                                        foldername,
+	                                        &tmp_err);
 	if (tmp_err != NULL) {
 		g_propagate_error (err, tmp_err);
 		return NULL;
@@ -1681,10 +1681,10 @@ kolab_mail_info_db_update_record (KolabMailInfoDb *self,
 	 * new entry or has properly been merged with existing data
 	 * if the entry did already exist
 	 */
-	ok = kolab_mail_info_db_sql_update_record (priv->kdb,
-	                                           record,
-	                                           foldername,
-	                                           &tmp_err);
+	ok = mail_info_db_sql_update_record (priv->kdb,
+	                                     record,
+	                                     foldername,
+	                                     &tmp_err);
 	if (! ok) {
 		g_propagate_error (err, tmp_err);
 		return FALSE;
@@ -1718,10 +1718,10 @@ kolab_mail_info_db_remove_record (KolabMailInfoDb *self,
 	g_assert (priv->is_up == TRUE);
 
 	/* TODO need a more efficient implementation here */
-	record = kolab_mail_info_db_sql_query_record (priv->kdb,
-	                                              uid,
-	                                              foldername,
-	                                              &tmp_err);
+	record = mail_info_db_sql_query_record (priv->kdb,
+	                                        uid,
+	                                        foldername,
+	                                        &tmp_err);
 	if (tmp_err != NULL) {
 		g_propagate_error (err, tmp_err);
 		return FALSE;
@@ -1738,10 +1738,10 @@ kolab_mail_info_db_remove_record (KolabMailInfoDb *self,
 
 	kolab_mail_info_db_record_free (record);
 
-	ok = kolab_mail_info_db_sql_remove_record (priv->kdb,
-	                                           uid,
-	                                           foldername,
-	                                           &tmp_err);
+	ok = mail_info_db_sql_remove_record (priv->kdb,
+	                                     uid,
+	                                     foldername,
+	                                     &tmp_err);
 	if (! ok) {
 		g_propagate_error (err, tmp_err);
 		return FALSE;
