@@ -36,6 +36,7 @@
 
 #include <libekolabutil/camel-system-headers.h>
 #include <libekolabutil/kolab-util-camel.h>
+#include <libekolabutil/kolab-util.h>
 
 #include "e-source-kolab-folder.h"
 #include "kolab-mail-access.h"
@@ -126,7 +127,7 @@ kolab_util_backend_get_relative_path_from_uri (const gchar *uri)
 	}
 	tmp = g_strdup (c_url->path);
 	camel_url_free (c_url);
-	if (tmp[0] == '/') {
+	if (tmp[0] == KOLAB_PATH_SEPARATOR) {
 		path = g_strdup (tmp+1);
 		g_free (tmp);
 	}
@@ -307,58 +308,6 @@ kolab_util_backend_modtime_set_on_ecalcomp (ECalComponent *ecalcomp)
 	e_cal_component_set_last_modified (ecalcomp, &itt);
 } /* kolab_util_backend_modtime_set_on_ecalcomp () */
 
-void
-kolab_util_backend_prepare_settings (KolabSettingsHandler *ksettings,
-                                     ESource *esource,
-                                     const gchar *password,
-                                     const gchar *sourcename,
-                                     const KolabSyncStrategyID *sync_value)
-{
-	/* Note: Currently (2.30), there is no good way of returning errors from
-	 * the backend to the frontends. So this helper function simply notifies
-	 * on stdout/stderr and proceeds.
-	 */
-	const gchar *prop_str = NULL;
-
-	GError *error = NULL;
-	g_debug ("%s()[%u] called.", __func__, __LINE__);
-	if (esource != NULL) {
-		prop_str = e_source_get_uid (esource);
-		(void)kolab_settings_handler_set_char_field (ksettings,
-		                                             KOLAB_SETTINGS_HANDLER_CHAR_FIELD_ESOURCE_UID,
-		                                             g_strdup (prop_str),
-		                                             &error);
-		if (error != NULL) {
-			g_warning ("%s()[%u] error: %s", __func__, __LINE__, error->message);
-			g_error_free (error);
-			error = NULL;
-		}
-	}
-	if (password != NULL) {
-		(void)kolab_settings_handler_set_char_field (ksettings,
-		                                             KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_PASSWORD,
-		                                             g_strdup (password),
-		                                             &error);
-		if (error != NULL) {
-			g_warning ("%s()[%u] error: %s", __func__, __LINE__, error->message);
-			g_error_free (error);
-			error = NULL;
-		}
-	}
-	if (sync_value != NULL) {
-		(void)kolab_settings_handler_set_value (ksettings,
-		                                        KOLAB_SETTINGS_HANDLER_TBL_SYNCSTRATEGY,
-		                                        sourcename,
-		                                        GUINT_TO_POINTER (*sync_value),
-		                                        &error);
-		if (error != NULL) {
-			g_warning ("%s()[%u] error: %s", __func__, __LINE__, error->message);
-			g_error_free (error);
-			error = NULL;
-		}
-	}
-} /* kolab_util_backend_prepare_settings () */
-
 gboolean
 kolab_util_backend_sqlite_db_new_open (KolabUtilSqliteDb **kdb,
                                        KolabSettingsHandler *ksettings,
@@ -535,7 +484,7 @@ kolab_util_backend_deploy_mode_by_backend (KolabMailAccess *koma,
 
 	if (online)
 		koma_mode = KOLAB_MAIL_ACCESS_OPMODE_ONLINE;
-	
+
 	tmp_mode = kolab_util_backend_deploy_mode_by_koma (koma,
 	                                                   koma_mode,
 	                                                   cancellable,
