@@ -57,6 +57,6 @@ validate_evolution_note_bug_3297386(const I_note *inote, gint stage)
 {
 	(void)stage;
 
-	assert_equal_gchar("BEGIN:VJOURNAL\r\nORGANIZER;CN=Hendrik Helwich:MAILTO:h.helwich@tarent.de\r\nX-EVOLUTION-RECIPIENTS:bill@gates.com;donald@duck.de\r\nDTSTART;VALUE=DATE:20110505\r\nEND:VJOURNAL\r\n",
+	assert_equal_gchar("BEGIN:VJOURNAL\r\nORGANIZER;CN=Hendrik Helwich:MAILTO:h.helwich@tarent.de\r\nX-EVOLUTION-RECIPIENTS:bill@gates.com\\;donald@duck.de\r\nDTSTART;VALUE=DATE:20110505\r\nEND:VJOURNAL\r\n",
 	                   inote->common->evolution_store);
 }
