@@ -85,9 +85,9 @@ assert_equal_gdate(gchar *expected, GDate *gdate)
 	}
 
 	gstr = g_strdup_printf("%04d-%02d-%02d",
-			g_date_get_year (gdate),
-			g_date_get_month (gdate),
-			g_date_get_day (gdate));
+	                       g_date_get_year (gdate),
+	                       g_date_get_month (gdate),
+	                       g_date_get_day (gdate));
 
 	gstr_new = g_string_new(gstr);
 	assert_equal(expected, gstr_new);
@@ -107,12 +107,12 @@ assert_equal_timestamp(gchar *expected, time_t *timestamp)
 	ts = gmtime(timestamp);
 
 	tstr = g_strdup_printf("%04d-%02d-%02d %02d:%02d:%02d",
-			ts->tm_year + 1900,
-			ts->tm_mon + 1,
-			ts->tm_mday,
-			ts->tm_hour,
-			ts->tm_min,
-			ts->tm_sec);
+	                       ts->tm_year + 1900,
+	                       ts->tm_mon + 1,
+	                       ts->tm_mday,
+	                       ts->tm_hour,
+	                       ts->tm_min,
+	                       ts->tm_sec);
 
 	g_debug("testing if string value '%s' is equal to expected value '%s'", tstr, expected);
 
@@ -155,17 +155,15 @@ assert_phone_in_list (GList *phone_nrs, gchar *nr_expected, Icontact_phone_type
 		if (p != NULL) {
 			g_debug ("testing if type '%d' matches expected type '%d'", p->type, type_expected);
 
-			if (p->type == type_expected)
-			{
+			if (p->type == type_expected) {
 				found_type = 1; /* types match */
 				g_debug ("matching type '%d' found", type_expected);
 				g_debug ("testing if number '%s' is equal to expected number '%s'",
-						p->number, nr_expected ? nr_expected : NULL);
+				         p->number, nr_expected ? nr_expected : NULL);
 				g_assert (p->number != NULL);
 				g_assert (nr_expected != NULL);
 
-				if (strcmp (p->number, nr_expected) == 0)
-				{
+				if (strcmp (p->number, nr_expected) == 0) {
 					g_debug ("matching number '%s' found", nr_expected);
 					matched_number = 1;
 					ret = p;
@@ -246,13 +244,13 @@ assert_email_in_list (GList *emails, gchar *smtp_address_exp, gchar *display_nam
 
 Address*
 assert_address_in_list (GList *addresses,
-		Icontact_address_type type,
-		gchar *street,
-		gchar *pobox,
-		gchar *locality,
-		gchar *region,
-		gchar *postal_code,
-		gchar *country)
+                        Icontact_address_type type,
+                        gchar *street,
+                        gchar *pobox,
+                        gchar *locality,
+                        gchar *region,
+                        gchar *postal_code,
+                        gchar *country)
 {
 	(void)type;
 
@@ -326,11 +324,11 @@ assert_address_in_list (GList *addresses,
 		}
 
 		if (matched_street == 1
-			&& matched_pobox == 1
-			&& matched_locality == 1
-			&& matched_region == 1
-			&& matched_postal_code == 1
-			&& matched_country == 1) {
+		    && matched_pobox == 1
+		    && matched_locality == 1
+		    && matched_region == 1
+		    && matched_postal_code == 1
+		    && matched_country == 1) {
 			return addr;
 		}
 
@@ -342,61 +340,60 @@ assert_address_in_list (GList *addresses,
 
 Alarm*
 assert_Alarm_in_list (GList *advancedAlarm, Alarm_type type, gint start_offset, gint end_offset,
-					  gint repeat_count, gint repeat_interval, gchar *display_text, gchar *audio_file,
-					  gchar *proc_param_program, gchar *proc_param_arguments,
-					  gchar *email_param_subject, gchar *email_param_mail_text)
+                      gint repeat_count, gint repeat_interval, gchar *display_text, gchar *audio_file,
+                      gchar *proc_param_program, gchar *proc_param_arguments,
+                      gchar *email_param_subject, gchar *email_param_mail_text)
 {
-	if (advancedAlarm != NULL)	/* evolution tasks have no advanced_alarm */
-	{
+	if (advancedAlarm != NULL) {	/* evolution tasks have no advanced_alarm */
 		while (advancedAlarm != NULL) {
-				Alarm *alarm = advancedAlarm->data;
-				gint failed = 0; /* bitmap for error location */
-				char *bm = NULL;
+			Alarm *alarm = advancedAlarm->data;
+			gint failed = 0; /* bitmap for error location */
+			char *bm = NULL;
 
-				g_assert (alarm != NULL);
+			g_assert (alarm != NULL);
 
-				g_debug ("advancedAlarm values: "
-						"AlarmType: %i, "
-						"start_offset: %i, "
-						"end_offset: %i, "
-						"repeat_count: %i, "
-						"repeat_interval: %i, "
-						"display_text: '%s', "
-						"audio_file: '%s', "
-						"proc_param_program: '%s', "
-						"proc_param_arguments: '%s', "
-						"email_param_subject: '%s', "
-						"email_param_mail_text: '%s'",
-						alarm->type, alarm->start_offset, alarm->end_offset, alarm->repeat_count,
-						alarm->repeat_interval, alarm->display_text ? alarm->display_text->str : "NULL",
-						alarm->audio_file ? alarm->audio_file->str : "NULL",
-						alarm->proc_param && alarm->proc_param->program ? alarm->proc_param->program->str : "NULL",
-						alarm->proc_param && alarm->proc_param->arguments ? alarm->proc_param->arguments->str : "NULL",
-						alarm->email_param && alarm->email_param->subject ? alarm->email_param->subject->str : "NULL",
-						alarm->email_param && alarm->email_param->mail_text ? alarm->email_param->mail_text->str : "NULL");
+			g_debug ("advancedAlarm values: "
+			         "AlarmType: %i, "
+			         "start_offset: %i, "
+			         "end_offset: %i, "
+			         "repeat_count: %i, "
+			         "repeat_interval: %i, "
+			         "display_text: '%s', "
+			         "audio_file: '%s', "
+			         "proc_param_program: '%s', "
+			         "proc_param_arguments: '%s', "
+			         "email_param_subject: '%s', "
+			         "email_param_mail_text: '%s'",
+			         alarm->type, alarm->start_offset, alarm->end_offset, alarm->repeat_count,
+			         alarm->repeat_interval, alarm->display_text ? alarm->display_text->str : "NULL",
+			         alarm->audio_file ? alarm->audio_file->str : "NULL",
+			         alarm->proc_param && alarm->proc_param->program ? alarm->proc_param->program->str : "NULL",
+			         alarm->proc_param && alarm->proc_param->arguments ? alarm->proc_param->arguments->str : "NULL",
+			         alarm->email_param && alarm->email_param->subject ? alarm->email_param->subject->str : "NULL",
+			         alarm->email_param && alarm->email_param->mail_text ? alarm->email_param->mail_text->str : "NULL");
 
-				CHECK_FAILED(alarm->type == type, failed, 1);
-				CHECK_FAILED(alarm->start_offset == start_offset, failed, 2);
-				CHECK_FAILED(alarm->end_offset == end_offset, failed, 3);
-				CHECK_FAILED(alarm->repeat_count == repeat_count, failed, 4);
-				CHECK_FAILED(alarm->repeat_interval == repeat_interval, failed, 5);
-				CHECK_FAILED(display_text == NULL || strcmp(alarm->display_text->str, display_text) == 0, failed, 6);
-				CHECK_FAILED(audio_file == NULL || strcmp(alarm->audio_file->str, audio_file) == 0, failed, 7);
-				CHECK_FAILED(proc_param_program == NULL || strcmp(alarm->proc_param->program->str, proc_param_program) == 0, failed, 8);
-				CHECK_FAILED(proc_param_arguments == NULL || strcmp(alarm->proc_param->arguments->str, proc_param_arguments) == 0, failed, 9);
-				/* email_param addresses list - own function assert_String_in_list() */
-				CHECK_FAILED(email_param_subject == NULL || strcmp(alarm->email_param->subject->str, email_param_subject) == 0, failed, 10);
-				CHECK_FAILED(email_param_mail_text == NULL || strcmp(alarm->email_param->mail_text->str, email_param_mail_text) == 0, failed, 11);
-				/* email_param attachments list - own function assert_String_in_list() */
+			CHECK_FAILED(alarm->type == type, failed, 1);
+			CHECK_FAILED(alarm->start_offset == start_offset, failed, 2);
+			CHECK_FAILED(alarm->end_offset == end_offset, failed, 3);
+			CHECK_FAILED(alarm->repeat_count == repeat_count, failed, 4);
+			CHECK_FAILED(alarm->repeat_interval == repeat_interval, failed, 5);
+			CHECK_FAILED(display_text == NULL || strcmp(alarm->display_text->str, display_text) == 0, failed, 6);
+			CHECK_FAILED(audio_file == NULL || strcmp(alarm->audio_file->str, audio_file) == 0, failed, 7);
+			CHECK_FAILED(proc_param_program == NULL || strcmp(alarm->proc_param->program->str, proc_param_program) == 0, failed, 8);
+			CHECK_FAILED(proc_param_arguments == NULL || strcmp(alarm->proc_param->arguments->str, proc_param_arguments) == 0, failed, 9);
+			/* email_param addresses list - own function assert_String_in_list() */
+			CHECK_FAILED(email_param_subject == NULL || strcmp(alarm->email_param->subject->str, email_param_subject) == 0, failed, 10);
+			CHECK_FAILED(email_param_mail_text == NULL || strcmp(alarm->email_param->mail_text->str, email_param_mail_text) == 0, failed, 11);
+			/* email_param attachments list - own function assert_String_in_list() */
 
-				bm = int_to_bitmask(failed);
-				g_debug ("checks for alarm: %s", bm);
-				g_free(bm);
+			bm = int_to_bitmask(failed);
+			g_debug ("checks for alarm: %s", bm);
+			g_free(bm);
 
-				if (!failed)
-					return alarm;
+			if (!failed)
+				return alarm;
 
-				advancedAlarm = advancedAlarm->next;
+			advancedAlarm = advancedAlarm->next;
 		}
 
 		g_debug ("no matching alarm found in list");
@@ -408,7 +405,7 @@ assert_Alarm_in_list (GList *advancedAlarm, Alarm_type type, gint start_offset,
 
 void
 assert_attendee_in_list(GList *attendees, gchar *display_name, gchar *smtp_address, Incidence_status status,
-		gboolean request_response, gboolean invitation_sent, Incidence_role role, Incidence_cutype type)
+                        gboolean request_response, gboolean invitation_sent, Incidence_role role, Incidence_cutype type)
 {
 	while (attendees != NULL) {
 		Attendee *attendee = attendees->data;
@@ -434,8 +431,7 @@ assert_attendee_in_list(GList *attendees, gchar *display_name, gchar *smtp_addre
 void
 assert_GDate_in_list(GList *date_list, gchar *value)
 {
-	while (date_list != NULL)
-	{
+	while (date_list != NULL) {
 		gchar *gstr = NULL;
 		GDate *date_element = date_list->data;
 
@@ -463,8 +459,7 @@ assert_GDate_in_list(GList *date_list, gchar *value)
 void
 assert_String_in_list(GList *string_list, gchar *value)
 {
-	while (string_list != NULL)
-	{
+	while (string_list != NULL) {
 		gchar *element = string_list->data;
 		g_assert (element != NULL);
 		if (strcmp(element, value) == 0) {
@@ -493,8 +488,8 @@ assert_custom_field_in_list (GList *custom_list, gchar *custom_field_type, gchar
 /* set value NULL in function call if element not available */
 void
 validate_iincidence(const I_incidence *iincidence, gchar *summary, gchar *location,
-		gchar *organizer_display_name, gchar *organizer_smtp_address,
-		gchar* start_date, gint stage)
+                    gchar *organizer_display_name, gchar *organizer_smtp_address,
+                    gchar* start_date, gint stage)
 {
 	(void)stage;
 
@@ -523,7 +518,7 @@ validate_iincidence(const I_incidence *iincidence, gchar *summary, gchar *locati
 
 void
 validate_icommon(const I_common *icommon, gchar* exp_product_id, gchar* exp_uid,
-		gchar *exp_body, gchar *exp_categories, Sensitivity exp_sensitivity, gchar *exp_creation_date, gchar *exp_last_modification_date, gint stage)
+                 gchar *exp_body, gchar *exp_categories, Sensitivity exp_sensitivity, gchar *exp_creation_date, gchar *exp_last_modification_date, gint stage)
 {
 	g_assert(icommon != NULL);
 	if (IS_TEST_STAGE_INTERN_TO_KMAIL(stage)) /* own value is written when kolab xml is created */
@@ -558,25 +553,20 @@ validate_icommon(const I_common *icommon, gchar* exp_product_id, gchar* exp_uid,
 	g_assert(icommon->last_modified_datetime != NULL);
 	g_assert(icommon->last_modified_datetime->date_time != NULL);
 
-	if(exp_creation_date != NULL && exp_last_modification_date != NULL)
-	{
+	if(exp_creation_date != NULL && exp_last_modification_date != NULL) {
 		assert_equal_timestamp(exp_creation_date, icommon->creation_datetime->date_time);
 		assert_equal_timestamp(exp_last_modification_date, icommon->last_modified_datetime->date_time);
 	}
-	else if(exp_creation_date == NULL && exp_last_modification_date != NULL)
-	{
+	else if(exp_creation_date == NULL && exp_last_modification_date != NULL) {
 		/* libekolabconv should have set last_modification_date as creation-date */
 		assert_equal_timestamp(exp_last_modification_date, icommon->creation_datetime->date_time);
 		assert_equal_timestamp(exp_last_modification_date, icommon->last_modified_datetime->date_time);
 	}
-	else if(exp_creation_date != NULL && exp_last_modification_date == NULL)
-	{
+	else if(exp_creation_date != NULL && exp_last_modification_date == NULL) {
 		/* libekolabconv should have set creation_date as last_modification_date */
 		assert_equal_timestamp(exp_creation_date, icommon->creation_datetime->date_time);
 		assert_equal_timestamp(exp_creation_date, icommon->last_modified_datetime->date_time);
-	}
-	else
-	{
+	} else {
 		/* libekolabconv should have used current system time for both */
 		assert_timestamp_not_older_than_10_seconds(icommon->creation_datetime->date_time);;
 		assert_timestamp_not_older_than_10_seconds(icommon->last_modified_datetime->date_time);
@@ -586,22 +576,22 @@ validate_icommon(const I_common *icommon, gchar* exp_product_id, gchar* exp_uid,
 
 void
 validate_recurrence(const Recurrence *recurrence, Recurrence_cycle cycle,
-		gint interval, gint range_number, gint *range_date, gint weekdays,
-		gint day_number, Month month)
+                    gint interval, gint range_number, gint *range_date, gint weekdays,
+                    gint day_number, Month month)
 {
 	g_assert(recurrence != NULL);
 
 	g_debug("recurrence (expected): recurrence_cycle: %i (%i), interval: %i (%i), range_number: %i (%i), "
-			"range_date %i-%i-%i (%i-%i-%i), weekdays: %i (%i), day_number: %i (%i), Month: %i (%i)",
-			recurrence->recurrence_cycle, cycle,
-			recurrence->interval, interval,
-			recurrence->range_number ? *recurrence->range_number : 0, range_number,
-			recurrence->range_date ? recurrence->range_date->year : 0, range_date ? *(range_date+2) : 0,
-			recurrence->range_date ? recurrence->range_date->month : 0, range_date ? *(range_date+1) : 0,
-			recurrence->range_date ? recurrence->range_date->day : 0, range_date ? *range_date : 0,
-			recurrence->weekdays, weekdays,
-			recurrence->day_number, day_number,
-			recurrence->month, month);
+	        "range_date %i-%i-%i (%i-%i-%i), weekdays: %i (%i), day_number: %i (%i), Month: %i (%i)",
+	        recurrence->recurrence_cycle, cycle,
+	        recurrence->interval, interval,
+	        recurrence->range_number ? *recurrence->range_number : 0, range_number,
+	        recurrence->range_date ? recurrence->range_date->year : 0, range_date ? *(range_date+2) : 0,
+	        recurrence->range_date ? recurrence->range_date->month : 0, range_date ? *(range_date+1) : 0,
+	        recurrence->range_date ? recurrence->range_date->day : 0, range_date ? *range_date : 0,
+	        recurrence->weekdays, weekdays,
+	        recurrence->day_number, day_number,
+	        recurrence->month, month);
 
 	g_assert(recurrence->recurrence_cycle == cycle);
 	g_assert(recurrence->interval == interval);
@@ -690,8 +680,7 @@ gchar
 
 	gchar *bitmask = g_new0(gchar, digits + digits/8);
 
-	while (digits--)
-	{
+	while (digits--) {
 		if (pos && (digits+1) % 8 == 0)
 			bitmask[pos++] = ' ';
 
@@ -764,40 +753,40 @@ strip_cr_cpy(const gchar *s)
 			*d++ = *s;
 	} while (*s++);
 
-    return cpy;
+	return cpy;
 }
 
 
 void
 validate_link_attachments(const I_common *icommon, ...)
 {
-        va_list ap;
-        gchar* v1, *v2;
-        GList *lal = icommon->link_attachments;
+	va_list ap;
+	gchar* v1, *v2;
+	GList *lal = icommon->link_attachments;
 	va_start(ap, icommon);
-        for (; lal != NULL; lal = lal->next) {
-        	v1 = (gchar*) lal->data;
-        	v2 = va_arg(ap, gchar*);
-        	g_assert_cmpstr (v1, ==, v2);
-        }
+	for (; lal != NULL; lal = lal->next) {
+		v1 = (gchar*) lal->data;
+		v2 = va_arg(ap, gchar*);
+		g_assert_cmpstr (v1, ==, v2);
+	}
 	v2 = va_arg(ap, gchar*);
 	g_assert(v2 == NULL);
-        va_end(ap);
+	va_end(ap);
 }
 
 void
 validate_inline_attachment_names(const I_common *icommon, ...)
 {
-        va_list ap;
-        gchar* v1, *v2;
-        GList *lal = icommon->inline_attachment_names;
+	va_list ap;
+	gchar* v1, *v2;
+	GList *lal = icommon->inline_attachment_names;
 	va_start(ap, icommon);
-        for (; lal != NULL; lal = lal->next) {
-        	v1 = (gchar*) lal->data;
-        	v2 = va_arg(ap, gchar*);
-        	g_assert_cmpstr (v1, ==, v2);
-        }
+	for (; lal != NULL; lal = lal->next) {
+		v1 = (gchar*) lal->data;
+		v2 = va_arg(ap, gchar*);
+		g_assert_cmpstr (v1, ==, v2);
+	}
 	v2 = va_arg(ap, gchar*);
 	g_assert(v2 == NULL);
-        va_end(ap);
+	va_end(ap);
 }
